==> xl-react-components-0.16.62.tgz: package/tests/e2e/scenario/widget/xl-react-widget-date-scenario.js <==
import Navigation from '../../dsl/common/navigation';
import TestBindings from '../../dsl/common/test-bindings';
import WidgetDate from '../../dsl/component/widget/widget-date';

describe('XL Widget Date Scenario', () => {
    afterAll(() => TestBindings.resetPristinity());
    beforeAll(() => Navigation.openWidgetElement('widgetDate1'));

    it('should have right initial state', () => {
        TestBindings.expectModelToEqual('November 9th 2016, 12:00:00 am');
        TestBindings.expectPristineToEqual('true');
        TestBindings.expectValidToEqual('true');
        WidgetDate.expectInputValue('Nov 9, 2016');
        WidgetDate.expectDescription('Date picker description');
        WidgetDate.expectLabel('Choose a date');
    });

    it('should show error about incorrect date format', () => {
        WidgetDate.setValue('b');
        WidgetDate.clickOnLabel();
        WidgetDate.expectError('Example: Dec 1, 2018');
        TestBindings.expectPristineToEqual('false');
        TestBindings.expectValidToEqual('false');
    });

    it('should allow to select new date and reflect that in model', () => {
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerPresent();
        WidgetDate.selectDay(13);
        WidgetDate.clickOnLabel();
        TestBindings.expectModelToEqual('November 13th 2016, 12:00:00 am');
        TestBindings.expectPristineToEqual('false');
        TestBindings.expectValidToEqual('true');
        WidgetDate.expectInputValue('Nov 13, 2016');
        WidgetDate.clickOnInput();
        WidgetDate.selectDay(9);
        WidgetDate.clickOnLabel();
    });

    it('should not open "select date" dialog when disabled', () => {
        WidgetDate.expectInputEnabled();
        WidgetDate.expectDatePickerNotPresent();
        TestBindings.toggleDisabled();
        WidgetDate.expectInputDisabled();
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerNotPresent();
        TestBindings.toggleDisabled();
        WidgetDate.expectInputEnabled();
    });

    it('should behave different in different view modes', () => {
        TestBindings.displayModeDisplay();
        WidgetDate.expectInputDisabled();
        TestBindings.displayModeCreation();
        WidgetDate.expectInputEnabled();
        TestBindings.displayModeEdit();
        WidgetDate.expectInputEnabled();
    });

    it('should not be able to choose date less than min date', () => {
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerPresent();
        WidgetDate.selectDay(1);
        WidgetDate.clickOnLabel();
        TestBindings.expectModelToEqual('November 9th 2016, 12:00:00 am');
    });

    it('should not be able to choose date greater than max date', () => {
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerPresent();
        WidgetDate.selectDay(25);
        WidgetDate.clickOnLabel();
        TestBindings.expectModelToEqual('November 9th 2016, 12:00:00 am');
    });
});

==> xl-react-components-0.21.9.tgz: package/tests/e2e/scenario/widget/xl-react-widget-date-scenario.js <==
import Navigation from '../../dsl/common/navigation';
import TestBindings from '../../dsl/common/test-bindings';
import WidgetDate from '../../dsl/component/widget/widget-date';

describe('XL Widget Date Scenario', () => {
    afterAll(() => TestBindings.resetPristinity());
    beforeAll(() => Navigation.openWidgetElement('widgetDate1'));

    it('should have right initial state', () => {
        TestBindings.expectModelToEqual('November 9th 2016, 12:00:00 am');
        TestBindings.expectPristineToEqual('true');
        TestBindings.expectValidToEqual('true');
        WidgetDate.expectInputValue('Nov 9, 2016');
        WidgetDate.expectDescription('Date picker description');
        WidgetDate.expectLabel('Choose a date');
    });

    it('should show error about incorrect date format', () => {
        WidgetDate.setValue('b');
        WidgetDate.clickOnLabel();
        WidgetDate.expectError('Example: Dec 1, 2018');
        TestBindings.expectPristineToEqual('false');
        TestBindings.expectValidToEqual('false');
    });

    it('should allow to select new date and reflect that in model', () => {
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerPresent();
        WidgetDate.selectDay('13');
        WidgetDate.clickOnLabel();
        TestBindings.expectModelToEqual('November 13th 2016, 12:00:00 am');
        TestBindings.expectPristineToEqual('false');
        TestBindings.expectValidToEqual('true');
        WidgetDate.expectInputValue('Nov 13, 2016');
        WidgetDate.clickOnInput();
        WidgetDate.selectDay('09');
        WidgetDate.clickOnLabel();
    });

    it('should not open "select date" dialog when disabled', () => {
        WidgetDate.expectInputEnabled();
        WidgetDate.expectDatePickerNotPresent();
        TestBindings.toggleDisabled();
        WidgetDate.expectInputDisabled();
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerNotPresent();
        TestBindings.toggleDisabled();
        WidgetDate.expectInputEnabled();
    });

    it('should behave different in different view modes', () => {
        TestBindings.displayModeDisplay();
        WidgetDate.expectInputDisabled();
        TestBindings.displayModeCreation();
        WidgetDate.expectInputEnabled();
        TestBindings.displayModeEdit();
        WidgetDate.expectInputEnabled();
    });

    it('should not be able to choose date less than min date', () => {
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerPresent();
        WidgetDate.selectDay('01');
        WidgetDate.clickOnLabel();
        TestBindings.expectModelToEqual('November 9th 2016, 12:00:00 am');
    });

    it('should not be able to choose date greater than max date', () => {
        WidgetDate.clickOnInput();
        WidgetDate.expectDatePickerPresent();
        WidgetDate.selectDay('25');
        WidgetDate.clickOnLabel();
        TestBindings.expectModelToEqual('November 9th 2016, 12:00:00 am');
    });
});
